Crate computeruse_computer_use

Crate computeruse_computer_use 

Gemini Computer Use - AI-powered autonomous desktop automation

This crate provides types and utilities for the Gemini Computer Use feature, which uses vision models to autonomously control desktop applications.

The actual Desktop integration lives in computeruse-rs, which re-exports and extends this crate’s functionality.

Structs

ComputerUseActionResponse
Response for a previous action
ComputerUseFunctionCall
Function call from Gemini Computer Use model
ComputerUsePreviousAction
Previous action to send back with screenshot (for multi-step)
ComputerUseResponse
Response from Computer Use backend
ComputerUseResult
Result of the computer use execution
ComputerUseStep
A single step in the computer use execution

Functions

call_computer_use_backend
Call the Gemini Computer Use backend to get the next action.
convert_normalized_to_screen
Convert normalized coordinates (0-999) to absolute screen coordinates.
translate_gemini_keys
Translate Gemini Computer Use key format to uiautomation format.

Type Aliases

ProgressCallback
Callback for progress updates during computer use execution